@@ -385,7 +385,7 @@ INSERT INTO photo_config
 ('use_photo_keyword',     '1',                '画像情報(検索キーワード)を使用',         0),
 ('use_photo_category',    '1',                '画像情報(カテゴリー)を使用',         0),
 ('use_photo_rate',    '1',                '画像情報(評価)を使用',         0),
-('layout_view_detail',   '<table class="photo_info"><caption>画像情報</caption><tbody><tr><th>ID</th><td>[#CT_ID#]</td></tr><tr><th>タイトル</th><td>[#CT_TITLE#]&nbsp;[#PERMALINK#]</td></tr><tr><th>撮影者</th><td>[#CT_AUTHOR#]</td></tr><tr><th>撮影日</th><td>[#CT_DATE#]</td></tr><tr><th>場所</th><td>[#CT_LOCATION#]</td></tr><tr><th>カメラ</th><td>[#CT_CAMERA#]</td></tr><tr><th>説明</th><td>[#CT_DESCRIPTION#]</td></tr><tr><th>カテゴリー</th><td>[#CT_CATEGORY#]</td></tr><tr><th>キーワード</th><td>[#CT_KEYWORD#]</td></tr><tr><th>評価</th><td>[#RATE#]</td></tr></tbody></table>', 'レイアウト(詳細表示)',               0),
+('layout_view_detail',   '<table class="photo_info table"><caption>画像情報</caption><tbody><tr><th>ID</th><td>[#CT_ID#]</td></tr><tr><th>タイトル</th><td>[#CT_TITLE#]&nbsp;[#PERMALINK#]</td></tr><tr><th>撮影者</th><td>[#CT_AUTHOR#]</td></tr><tr><th>撮影日</th><td>[#CT_DATE#]</td></tr><tr><th>場所</th><td>[#CT_LOCATION#]</td></tr><tr><th>カメラ</th><td>[#CT_CAMERA#]</td></tr><tr><th>説明</th><td>[#CT_DESCRIPTION#]</td></tr><tr><th>カテゴリー</th><td>[#CT_CATEGORY#]</td></tr><tr><th>キーワード</th><td>[#CT_KEYWORD#]</td></tr><tr><th>評価</th><td>[#RATE#]</td></tr></tbody></table>', 'レイアウト(詳細表示)',               0),
 ('output_head',      '0', 'HTMLヘッダ出力', 0),
 ('head_view_detail',   '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_SUMMARY#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />', 'ヘッダ出力(詳細表示)',               0);
 
@@ -401,7 +401,7 @@ CREATE TABLE quiz_config (
     qc_description       VARCHAR(80)    DEFAULT ''                    NOT NULL,      -- 説明
     qc_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
     PRIMARY KEY          (qc_id)
-) TYPE=innodb;
+) ENGINE=innodb;
 
 -- クイズパターンセットIDマスター
 DROP TABLE IF EXISTS quiz_set_id;
@@ -422,7 +422,7 @@ CREATE TABLE quiz_set_id (
     qs_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
     PRIMARY KEY          (qs_serial),
     UNIQUE               (qs_id,  qs_history_index)
-) TYPE=innodb;
+) ENGINE=innodb;
 
 -- クイズ問題定義マスター
 DROP TABLE IF EXISTS quiz_item_def;
@@ -447,7 +447,7 @@ CREATE TABLE quiz_item_def (
     qd_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
     PRIMARY KEY          (qd_serial),
     UNIQUE               (qd_set_id,   qd_id,  qd_history_index)
-) TYPE=innodb;
+) ENGINE=innodb;
 
 -- クイズユーザ回答トラン
 DROP TABLE IF EXISTS quiz_user_post;
@@ -462,7 +462,7 @@ CREATE TABLE quiz_user_post (
     qp_access_log_serial INT            DEFAULT 0                     NOT NULL,      -- アクセスログ番号
     PRIMARY KEY          (qp_serial),
     UNIQUE               (qp_mobile_id,   qp_set_id,  qp_question_id)
-) TYPE=innodb;
+) ENGINE=innodb;
 
 INSERT INTO quiz_set_id (qs_id,         qs_name,              qs_index)
 VALUES                  ('default_set', 'デフォルトパターン', 0);
