@@ -8,7 +8,7 @@
  *
  * @package    カスタム検索
  * @author     株式会社 毎日メディアサービス
- * @copyright  Copyright 2010-2013 株式会社 毎日メディアサービス.
+ * @copyright  Copyright 2010-2014 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.m-media.co.jp
@@ -102,12 +102,13 @@ class custom_searchDb extends BaseDb
 	 * @param bool		$isTargetEvent		イベント情報を検索対象とするかどうか
 	 * @param bool		$isTargetBbs		BBSを検索対象とするかどうか
 	 * @param bool		$isTargetPhoto		フォトギャラリーを検索対象とするかどうか
+	 * @param bool		$isTargetWiki		Wikiを検索対象とするかどうか
 	 * @param bool		$contentUsePassword	汎用コンテンツのパスワード閲覧制限するかどうか
 	 * @param function	$callback			コールバック関数
 	 * @return int,bool						$limitが0のときintで項目数、$limitが0以外のときはbool(true=1行以上レコード取得、false=レコードなし)
 	 */
 	function searchContentsByKeyword($limit, $page, $keywords, $categoryInfo, $langId, $isAll, $isTargetContent, $isTargetUser, $isTargetBlog, 
-									$isTargetProduct, $isTargetEvent, $isTargetBbs, $isTargetPhoto, $contentUsePassword, $callback = NULL)
+									$isTargetProduct, $isTargetEvent, $isTargetBbs, $isTargetPhoto, $isTargetWiki, $contentUsePassword, $callback = NULL)
 	{
 		$offset = $limit * ($page -1);
 		if ($offset < 0) $offset = 0;
@@ -350,6 +351,36 @@ class custom_searchDb extends BaseDb
 				}
 			}
 		}
+		// ##### Wikiの検索条件 #####
+		if (!empty($isTargetWiki)){
+			if (!empty($queryStr)) $queryStr .= ' UNION ';
+			$queryStr .= 'SELECT DISTINCT \'wiki\' AS type, wc_id AS id, wc_id AS name, wc_content_dt AS dt, 0 AS group_id ';
+			$queryStr .= 'FROM wiki_content LEFT JOIN _login_user ON wc_create_user_id = lu_id AND lu_deleted = false ';
+			$queryStr .=   'WHERE wc_deleted = false ';		// 未削除
+			$queryStr .=     'AND wc_visible = true ';		// 公開中
+			$queryStr .=     'AND wc_type = \'\' ';			// コンテンツ本体
+			
+			if (!empty($keywords)){
+				for ($i = 0; $i < count($keywords); $i++){
+					$keyword = addslashes($keywords[$i]);		// 「'"\」文字をエスケープ
+					$queryStr .=    'AND (wc_id LIKE \'%' . $keyword . '%\' ';		// WikiコンテンツID
+					$queryStr .=    'OR wc_data LIKE \'%' . $keyword . '%\') ';		// Wikiコンテンツ
+				}
+			}
+
+			// 回避ページ
+			$escapePages = array(	'RecentChanges',	// Modified page list
+									'RecentDeleted', 	// Removeed page list
+									'InterWikiName',	// Set InterWiki definition here
+									'MenuBar');       	// メニューバー
+									
+			// 回避ページ
+			for ($i = 0; $i < count($escapePages); $i++){
+				$queryStr .=    'AND wc_id != ? '; $params[] = $escapePages[$i];
+			}
+			$keyword = addslashes(':');// 「:xxxxx」(設定ページ)の「'"\」文字をエスケープ
+			$queryStr .=    'AND wc_id NOT LIKE \'' . $keyword . '%\' ';
+		}
 		if (empty($limit)){			// 項目数取得の場合
 			$ret = $this->selectRecordCount($queryStr, $params);
 		} else {
@@ -500,5 +531,21 @@ class custom_searchDb extends BaseDb
 		$ret = $this->selectRecord($queryStr, array($id, $langId), $row);
 		return $ret;
 	}
+	/**
+	 * Wikiページデータの取得
+	 *
+	 * @param string  $id			WikiコンテンツID
+	 * @param array   $row			レコード
+	 * @return bool					取得 = true, 取得なし= false
+	 */
+	function getWiki($id, &$row)
+	{
+		$queryStr  = 'SELECT * FROM wiki_content ';
+		$queryStr .=   'WHERE wc_deleted = false ';	// 削除されていない
+		$queryStr .=    'AND wc_type = ? ';
+		$queryStr .=   'AND wc_id = ? ';
+		$ret = $this->selectRecord($queryStr, array('', $id), $row);
+		return $ret;
+	}
 }
 ?>
