@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2013 Magic3 Project.
+ * @copyright  Copyright 2006-2014 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainTopWidgetContainer.php 5631 2013-02-10 11:34:25Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/photo_mainBaseWidgetContainer.php');
@@ -50,6 +50,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 	private $postPrice;		// 価格表示用
 	private $categoryWithPwdArray;	// パスワードが必要なカテゴリー
 	const CSS_FILE = '/style.css';		// CSSファイルのパス
+	const CSS_FILE_BOOTSTRAP = '/style_bootstrap.css';		// Bootstrap用CSSファイル
 	const NOT_FOUND_ICON_FILE = 		'/images/system/notfound128.gif';		// 写真が見つからないアイコン
 	const BACK_ICON_FILE = '/images/system/back.png';		// 「戻る」アイコン
 	const PREV_ICON_FILE = '/images/system/previous.png';		// 「前へ」アイコン
@@ -58,9 +59,9 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 	const LOAD_ICON_FILE = '/loader.gif';			// ロード中アイコン
 	const RATY_IMAGE_DIR = '/jquery/raty/img';		// jquery.raty画像パス
 	const LINK_PAGE_COUNT		= 10;			// リンクページ数
-	const BACK_BUTTON_TITLE = '戻る';		// 「戻る」ボタンタイトル
-	const PREV_BUTTON_TITLE = '前へ';		// 「前へ」ボタンタイトル
-	const NEXT_BUTTON_TITLE = '次へ';		// 「次へ」ボタンタイトル
+	const BACK_BUTTON_TITLE = '一覧へ戻る';		// 「戻る」ボタンタイトル
+	const PREV_BUTTON_TITLE = '前の画像へ';		// 「前へ」ボタンタイトル
+	const NEXT_BUTTON_TITLE = '次の画像へ';		// 「次へ」ボタンタイトル
 	const SEARCH_FIELD_HEAD = 'photo_main_item';			// フィールド名の先頭文字列
 	const SEARCH_FIELD_CLASS_HEAD = 'photo_main_';			// フィールドクラスの先頭文字列
 	const TARGET_WIDGET = 'photo_shop';			// 画像購入ウィジェット
@@ -99,14 +100,26 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		
 		$act = $request->trimValueOf('act');
 		if ($act == 'search'){
-			return 'main_list.tmpl.html';
+			if ($this->_renderType == M3_RENDER_BOOTSTRAP){
+				return 'index_bootstrap.tmpl.html';
+			} else {
+				return 'index.tmpl.html';
+			}
 		} else if ($act == 'inputcart'){			// カートに入れる
 			return '';
 		} else {
 			if (empty($this->photoId)){
-				return 'main_list.tmpl.html';
+				if ($this->_renderType == M3_RENDER_BOOTSTRAP){
+					return 'index_bootstrap.tmpl.html';
+				} else {
+					return 'index.tmpl.html';
+				}
 			} else {
-				return 'photo_detail.tmpl.html';
+				if ($this->_renderType == M3_RENDER_BOOTSTRAP){
+					return 'photo_detail_bootstrap.tmpl.html';
+				} else {
+					return 'photo_detail.tmpl.html';
+				}
 			}
 		}
 	}
@@ -183,7 +196,9 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 	 */
 	function _addCssFileToHead($request, &$param)
 	{
-		return $this->getUrl($this->gEnv->getCurrentWidgetCssUrl() . self::CSS_FILE);
+		$cssFile = $this->gEnv->getCurrentWidgetCssUrl() . self::CSS_FILE;
+		if ($this->_renderType == M3_RENDER_BOOTSTRAP) $cssFile = $this->gEnv->getCurrentWidgetCssUrl() . self::CSS_FILE_BOOTSTRAP;
+		return $this->getUrl($cssFile);
 	}
 	/**
 	 * 一覧画面表示
@@ -202,7 +217,11 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			$this->fieldInfoArray = array();			// 項目定義
 		
 			// デフォルトの検索テンプレート作成
-			$searchTemplate = $this->getParsedTemplateData(photo_mainCommonDef::DEFAULT_SEARCH_AREA_TMPL, array($this, '_makeSearcheTemplate'));// デフォルト用の検索テンプレート
+			if ($this->_renderType == M3_RENDER_BOOTSTRAP){
+				$searchTemplate = $this->getParsedTemplateData(photo_mainCommonDef::DEFAULT_SEARCH_AREA_BOOTSTRAP_TMPL, array($this, '_makeSearcheTemplate'));// デフォルト用の検索テンプレート
+			} else {
+				$searchTemplate = $this->getParsedTemplateData(photo_mainCommonDef::DEFAULT_SEARCH_AREA_TMPL, array($this, '_makeSearcheTemplate'));// デフォルト用の検索テンプレート
+			}
 		} else {
 			$searchTemplate = $paramObj->searchTemplate;		// 検索用テンプレート
 			if (!empty($paramObj->fieldInfo)) $this->fieldInfoArray = $paramObj->fieldInfo;			// 項目定義
@@ -321,26 +340,29 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		$totalCount = self::$_mainDb->searchPhotoItemCount($this->_langId, null/*開始日時*/, null/*終了日時*/, $parsedKeywords/*キーワード*/,
 															$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/, $limitedCategory);
 
-		// リンク文字列作成、ページ番号調整
-		$this->calcPage($pageNo, $totalCount, $this->viewCount, $pageCount, $startNo, $endNo);
-		
-		// 検索条件を設定した場合で画像数が0のときはメッセージ表示
-		if ($startNo > $endNo){
-			if (!empty($parsedKeywords) || !empty($this->categoryArray) || !empty($this->authorArray)) $this->setUserErrorMsg('画像が見つかりません');
+		// リンク文字列作成
+		//$this->calcPage($pageNo, $totalCount, $this->viewCount, $pageCount, $startNo, $endNo);
+		$ret = $this->calcPageLink($pageNo, $totalCount, $this->viewCount);
+		if ($ret){		// ページリンク作成可能な場合
+			// ページリンク作成
+			$linkStyle = 0;			// HTMLの出力タイプ
+			if ($this->_renderType == M3_RENDER_BOOTSTRAP) $linkStyle = 2;		// Bootstrap型テンプレートの場合
+			$pageLink = $this->createPageLink($pageNo, self::LINK_PAGE_COUNT, $this->gEnv->createCurrentPageUrl(), $urlParams, $linkStyle);
+			//$pageLink = $this->createPageLink($pageNo, self::LINK_PAGE_COUNT, $this->gEnv->createCurrentPageUrl(), $urlParams);
+			if (!empty($pageLink)){
+				$this->tmpl->setAttribute('page_link_top', 'visibility', 'visible');		// リンク表示
+				$this->tmpl->setAttribute('page_link_bottom', 'visibility', 'visible');		// リンク表示
+				$this->tmpl->addVar("page_link_top", "page_link", $pageLink);
+				$this->tmpl->addVar("page_link_bottom", "page_link", $pageLink);
+			}
+			// AJAX用URL、詳細画面用URL
+			$ajaxUrl = 'act=getlist&' . M3_REQUEST_PARAM_PAGE_NO . '=' . $pageNo . $urlParams;
+			$this->tmpl->setAttribute('get_photo', 'visibility', 'visible');		// 画像取得
+			$this->tmpl->addVar("get_photo", "ajax_url", $ajaxUrl);
+		} else {		// 画像なし、あるいは、ページ番号が正しくない場合
+			$this->setUserErrorMsg('画像が見つかりません');
 		}
 		
-		// ページリンク作成
-		$pageLink = $this->createPageLink($pageNo, $pageCount, self::LINK_PAGE_COUNT, $this->gEnv->createCurrentPageUrl(), $urlParams);
-		if (!empty($pageLink)){
-			$this->tmpl->setAttribute('page_link_top', 'visibility', 'visible');		// リンク表示
-			$this->tmpl->setAttribute('page_link_bottom', 'visibility', 'visible');		// リンク表示
-			$this->tmpl->addVar("page_link_top", "page_link", $pageLink);
-			$this->tmpl->addVar("page_link_bottom", "page_link", $pageLink);
-		}
-
-		// AJAX用URL、詳細画面用URL
-		$ajaxUrl = 'act=getlist&' . M3_REQUEST_PARAM_PAGE_NO . '=' . $pageNo . $urlParams;
-		
 		// 検索カテゴリ情報を取得
 		$ret = $this->categoryDb->getAllCategoryForMenu($this->_langId, $menuCategoryArray, $rows);
 		if ($ret){
@@ -360,7 +382,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			}
 			if (!empty($category)) $this->categoryInfoArray[$parentCategory] = $category;
 		}
-		
+
 		// ##### 検索画面作成 #####
 		if (!empty(self::$_configArray[photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD]) && empty($this->authCategory)){// 画像カテゴリーのパスワード制限ありで参照可能カテゴリーがないとき
 			$fieldOutput = '';		// 検索画面なし
@@ -391,12 +413,11 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			$this->tmpl->addVar("search_script", "sort",		$this->sortKey . '-' . $this->sortDirection);		// デフォルトのソート順
 		}
 		
-		// 画面埋め込みデータ
+		// その他画面埋め込みデータ
 		$this->tmpl->addVar("_widget", "photo_count", $this->convertToDispString($this->viewCount));
 		$this->tmpl->addVar("_widget", "load_icon_url", $this->getUrl($this->gEnv->getCurrentWidgetImagesUrl() . self::LOAD_ICON_FILE));			// ロード中アイコン
 		$this->tmpl->addVar("_widget", "photo_detail_url", $this->getUrl($this->gEnv->getDefaultUrl(), true/*リンク用*/));		// 詳細画面へのリンク
 		$this->tmpl->addVar("_widget", "photo_detail_url_others", $urlParams);		// 詳細画面へのリンクの付加URLパラメータ
-		$this->tmpl->addVar("_widget", "ajax_url", $ajaxUrl);
 		$this->tmpl->addVar('_widget', 'raty_image_url', $this->getUrl($this->gEnv->getScriptsUrl() . self::RATY_IMAGE_DIR));	// jquery.raty画像パス
 	}
 	/**
@@ -1130,67 +1151,6 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		$tmpl->addVar("_tmpl", "search_reset_id",	photo_mainCommonDef::SEARCH_RESET_ID);		// 検索エリアリセットボタンのタグID
 		$tmpl->addVar("_tmpl", "search_sort_id",	photo_mainCommonDef::SEARCH_SORT_ID);		// 検索エリアソートメニューのタグID
 	}
-	/**
-	 * ページ番号計算処理
-	 *
-	 * @param int $pageNo			ページ番号(1～)。ページ番号が範囲外にある場合は自動的に調整
-	 * @param int $totalCount		総項目数
-	 * @param int $viewItemCount	1ページあたりの項目数
-	 * @param int $pageCount		戻り値、ページ総数(1～)。
-	 * @param int $startNo			戻り値、先頭項目番号(1～)。
-	 * @param int $endNo			戻り値、最後項目番号(1～)。
-	 * @return 						なし
-	 */
-	function calcPage(&$pageNo, $totalCount, $viewItemCount, &$pageCount, &$startNo, &$endNo)
-	{
-		// 表示するページ番号の修正
-		$pageCount = (int)(($totalCount -1) / $viewItemCount) + 1;		// 総ページ数
-		if ($pageNo < 1) $pageNo = 1;
-		if ($pageNo > $pageCount) $pageNo = $pageCount;
-		$startNo = ($pageNo -1) * $viewItemCount +1;		// 先頭の行番号
-		$endNo = $pageNo * $viewItemCount > $totalCount ? $totalCount : $pageNo * $viewItemCount;// 最後の行番号
-	}
-	/**
-	 * ページリンク作成
-	 *
-	 * @param int $pageNo			ページ番号(1～)。
-	 * @param int $pageCount		総項目数
-	 * @param int $linkCount		最大リンク数
-	 * @param string $baseUrl		リンク用のベースURL
-	 * @param string $urlParams		オプションのURLパラメータ
-	 * @return string				リンクHTML
-	 */
-	function createPageLink($pageNo, $pageCount, $linkCount, $baseUrl, $urlParams)
-	{
-		// ページング用リンク作成
-		$pageLink = '';
-		if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
-			// ページ数1から「LINK_PAGE_COUNT」までのリンクを作成
-			$maxPageCount = $pageCount < $linkCount ? $pageCount : $linkCount;
-			for ($i = 1; $i <= $maxPageCount; $i++){
-				if ($i == $pageNo){
-					$link = '&nbsp;[' . $i . ']';
-				} else {
-					$linkUrl = $this->getUrl($baseUrl . '&' . M3_REQUEST_PARAM_PAGE_NO . '=' . $i . $urlParams, true/*リンク用*/);
-					$link = '&nbsp;<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >[' . $i . ']</a>';
-				}
-				$pageLink .= $link;
-			}
-			// 残りは「...」表示
-			if ($pageCount > $linkCount) $pageLink .= '&nbsp;...';
-		}
-		if ($pageNo > 1){		// 前ページがあるとき
-			$linkUrl = $this->getUrl($baseUrl . '&' . M3_REQUEST_PARAM_PAGE_NO . '=' . ($pageNo -1) . $urlParams, true/*リンク用*/);
-			$link = '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >[前へ]</a>';
-			$pageLink = $link . $pageLink;
-		}
-		if ($pageNo < $pageCount){		// 次ページがあるとき
-			$linkUrl = $this->getUrl($baseUrl . '&' . M3_REQUEST_PARAM_PAGE_NO . '=' . ($pageNo +1) . $urlParams, true/*リンク用*/);
-			$link = '&nbsp;<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >[次へ]</a>';
-			$pageLink .= $link;
-		}
-		return $pageLink;
-	}
 	/**
 	 * 検索条件フィールド作成
 	 *
